import { ChainQueryType, ChainSpecificQuery } from "./request";
import { BinaryReader } from "./BinaryReader";
import { ChainSpecificResponse } from "./response";
export interface SolanaPdaEntry {
    programAddress: Uint8Array;
    seeds: Uint8Array[];
}
export declare const SolanaMaxSeeds = 16;
export declare const SolanaMaxSeedLen = 32;
export declare class SolanaPdaQueryRequest implements ChainSpecificQuery {
    pdas: SolanaPdaEntry[];
    commitment: string;
    minContextSlot: bigint;
    dataSliceOffset: bigint;
    dataSliceLength: bigint;
    constructor(commitment: "finalized", pdas: SolanaPdaEntry[], minContextSlot?: bigint, dataSliceOffset?: bigint, dataSliceLength?: bigint);
    type(): ChainQueryType;
    serialize(): Uint8Array;
    static from(bytes: string | Uint8Array): SolanaPdaQueryRequest;
    static fromReader(reader: BinaryReader): SolanaPdaQueryRequest;
}
export declare class SolanaPdaQueryResponse implements ChainSpecificResponse {
    slotNumber: bigint;
    blockTime: bigint;
    blockHash: Uint8Array;
    results: SolanaPdaResult[];
    constructor(slotNumber: bigint, blockTime: bigint, blockHash: Uint8Array, results: SolanaPdaResult[]);
    type(): ChainQueryType;
    serialize(): Uint8Array;
    static from(bytes: string | Uint8Array): SolanaPdaQueryResponse;
    static fromReader(reader: BinaryReader): SolanaPdaQueryResponse;
}
export interface SolanaPdaResult {
    account: Uint8Array;
    bump: number;
    lamports: bigint;
    rentEpoch: bigint;
    executable: boolean;
    owner: Uint8Array;
    data: Uint8Array;
}
